==> dcl_5.3-2.tar.gz: dcl-5.3/src/grph2/umpack/umfmap.f <==
*-----------------------------------------------------------------------
*     FILL PATTERN ON MAP (GEOGRAPHIC COORDINATE)
*-----------------------------------------------------------------------
*     Copyright (C) 2000 GFD Dennou Club. All rights reserved.
*-----------------------------------------------------------------------
      SUBROUTINE UMFMAP(CDSN)

      CHARACTER CDSN*(*)

      PARAMETER (NPMAX=8192)

      REAL      XLAT(NPMAX),XLON(NPMAX)
      CHARACTER CDSNX*80,CMSG*80
      INTEGER   IPATLAND, IPATLAKE
      LOGICAL   LFILLAKE

      EXTERNAL  IUFOPN


*     / GET INTERNAL PARAMETERS /

      CALL UMIGET('INDEXOUT',INDEX)
      CALL UMIGET('ITYPEOUT',ITYPE)
      CALL UMIGET('IPATLAND',IPATLAND)
      CALL UMIGET('IPATLAKE',IPATLAKE)
      CALL UMLGET('LFILLAKE',LFILLAKE)

*     / INQUIRE OUTLINE FILE /

      CALL UMQFNM(CDSN,CDSNX)
      IF (CDSNX.EQ.' ') THEN
        CMSG='OUTLINE FILE = '//CDSN(1:LENC(CDSN))
        CALL MSGDMP('M','UMPMAP',CMSG)
        CALL MSGDMP('E','UMPMAP','OUTLINE FILE DOES NOT EXIST.')
      END IF

*     / OPEN OUTLINE FILE /

      IU=IUFOPN()
      OPEN(IU,FILE=CDSNX,FORM='UNFORMATTED',STATUS='OLD')
      REWIND(IU)

*     / READ OUTLINE DATA AND PLOT /

   10 CONTINUE
        READ(IU,IOSTAT=IOS) NPTS,IGID,XLATMX,XLATMN,XLONMX,XLONMN,
     +     (XLAT(I),XLON(I),I=1,NPTS/2)
        IF (IOS.EQ.0) THEN
          IF (NPTS .GT. 10 .OR. 
     +      (XLON(1).EQ.XLON(NPTS/2) .AND. XLAT(1).EQ.XLAT(NPTS/2))) 
     +        THEN
            IF (IGID.EQ.1) THEN
              CALL SGTNZU(NPTS/2,XLON,XLAT,IPATLAND)
            ELSE IF (IGID.EQ.2) THEN
              IF (LFILLAKE) CALL SGTNZU(NPTS/2,XLON,XLAT,IPATLAKE)
            END IF
          END IF
        END IF
      IF (IOS.EQ.0) GO TO 10
   20 CONTINUE

      CLOSE(IU)

      END

==> dcl_5.4.9.orig.tar.gz: dcl-5.4.9/src/grph2/umpack/umfmap.f <==
*-----------------------------------------------------------------------
*     FILL PATTERN ON MAP (GEOGRAPHIC COORDINATE)
*-----------------------------------------------------------------------
*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
*-----------------------------------------------------------------------
      SUBROUTINE UMFMAP(CDSN)

      CHARACTER CDSN*(*)

      PARAMETER (NPMAX=8192)

      REAL      XLAT(NPMAX),XLON(NPMAX)
      CHARACTER CDSNX*80,CMSG*80
      LOGICAL   LFLAKE

      EXTERNAL  IUFOPN


*     / SET INTERNAL PARAMETERS /

      CALL SGISET('IRMODE', 0)

*     / GET INTERNAL PARAMETERS /

      CALL SGIGET('IBGCLI',IBGCLI)
      CALL UMIGET('IPATLAND',IPLAND)
      CALL UMIGET('IPATLAKE',IPLAKE)
      CALL UMLGET('LFILLAKE',LFLAKE)
      IF (.NOT. LFLAKE) IPLAKE = IBGCLI*1000+999

*     / INQUIRE OUTLINE FILE /

      CALL UMQFNM(CDSN,CDSNX)
      IF (CDSNX.EQ.' ') THEN
        CMSG='OUTLINE FILE = '//CDSN(1:LENC(CDSN))
        CALL MSGDMP('M','UMPMAP',CMSG)
        CALL MSGDMP('E','UMPMAP','OUTLINE FILE DOES NOT EXIST.')
      END IF

*     / OPEN OUTLINE FILE /

      IU=IUFOPN()
      OPEN(IU,FILE=CDSNX,FORM='UNFORMATTED',STATUS='OLD')
      REWIND(IU)

*     / READ OUTLINE DATA AND PLOT /

   10 CONTINUE
        READ(IU,IOSTAT=IOS) NPTS,IGID,XLATMX,XLATMN,XLONMX,XLONMN,
     +     (XLAT(I),XLON(I),I=1,NPTS/2)
        IF (IOS.EQ.0) THEN
          IF (NPTS .GT. 10 .OR. 
     +      (XLON(1).EQ.XLON(NPTS/2) .AND. XLAT(1).EQ.XLAT(NPTS/2))) 
     +        THEN
            IF (IGID.EQ.1) THEN
             CALL SGTNZU(NPTS/2,XLON,XLAT,IPLAND)
            ELSE IF (IGID.EQ.2) THEN
              CALL SGTNZU(NPTS/2,XLON,XLAT,IPLAKE)
            END IF
          END IF
        END IF
      IF (IOS.EQ.0) GO TO 10
   20 CONTINUE

      CLOSE(IU)

      END
